/* { dg-do compile } */
#include <altivec.h>
vector char bool _4 ;
vector char unsigned _31 ;
vector char signed _59 ;
bool _84 ;
vector pixel _89 ;
vector int bool _95 ;
vector short bool _102 ;
vector unsigned int _122 ;
vector unsigned short _129 ;
vector signed int _150 ;
vector signed short _157 ;
vector int bool _179 ;
vector int short bool _186 ;
vector unsigned int _206 ;
vector int unsigned short _213 ;
vector signed int _234 ;
vector int signed short _241 ;
vector float _339 ;
