// { dg-do assemble  }
// { dg-options "-fexceptions -g" }
// GROUPS passed exceptions
// except file
// Message-Id: <9211061330.AA29334@ifad.dk>
// From: erik@ifad.dk (Erik Toubro Nielsen)
// Subject: g++-2.3.1 gets fatal signal with -g and -fhandle-exceptions
// Date: Fri, 6 Nov 92 14:30:33 +0100

int main()
{
  return 0;
}
