// { dg-do assemble  }
// Bug: g++ tries to generate initialization semantics for a Node from an int,
// and fails.

struct Node
{				// { dg-error "" } 
  Node* child[2];
};

void bug(int i)
{
  Node* q = new Node(i);	// { dg-error "" } 
}
