/* Test the `vreinterpretu8_s64' ARM Neon intrinsic.  */
/* This file was autogenerated by neon-testgen.  */

/* { dg-do assemble } */
/* { dg-require-effective-target arm_neon_ok } */
/* { dg-options "-save-temps -O0 -mfpu=neon -mfloat-abi=softfp" } */

#include "arm_neon.h"

void test_vreinterpretu8_s64 (void)
{
  uint8x8_t out_uint8x8_t;
  int64x1_t arg0_int64x1_t;

  out_uint8x8_t = vreinterpret_u8_s64 (arg0_int64x1_t);
}

/* { dg-final { cleanup-saved-temps } } */
